Class: Conduit::ResponsesController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- Conduit::ResponsesController
- Defined in:
- app/controllers/conduit/responses_controller.rb
Instance Method Summary collapse
-
#create ⇒ Object
TODO: Determine the actual param the posted content will be stored in, and modify the code below.
Instance Method Details
#create ⇒ Object
TODO: Determine the actual param the posted content will be stored in, and modify the code below
7 8 9 10 11 |
# File 'app/controllers/conduit/responses_controller.rb', line 7 def create request = Conduit::Request.find(params[:request_id]) request.responses.create(content: params[:content]) render nothing: true end |